#
# spec file for package openvswitch
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#
# needssslcertforbuild


# Disable building the external kernel datapath by default
%bcond_with kmp
%ifarch aarch64 x86_64 %{ix86}
# DPDK enabled by default
%bcond_without dpdk
%else
# No DPDK support on these architectures
%bcond_with dpdk
%endif
# The testsuite is somewhat fragile for continuous testing in OBS
# but keep it here as an option
%bcond_with check
Name:           openvswitch
Version:        2.7.0
Release:        7.1
Summary:        An open source, production quality, multilayer virtual switch
# All code is Apache-2.0 except
# - lib/sflow* which is SISSL
# - utilities/bugtool which is LGPL-2.1
License:        Apache-2.0 and LGPL-2.1 and SISSL
Group:          Productivity/Networking/System
Url:            http://openvswitch.org/
Source0:        http://openvswitch.org/releases/openvswitch-%{version}.tar.gz
Source1:        preamble
Source89:       Module.supported.updates
# PATCH-FIX-UPSTREAM 0001-ofp-util-Fix-buffer-overread-in-ofputil_pull_queue_g.patch
# Upstream fix (present in 2.7 branch) to fix CVE-2017-9214
# See https://nvd.nist.gov/vuln/detail/CVE-2017-9214
Patch1:         0001-ofp-util-Fix-buffer-overread-in-ofputil_pull_queue_g.patch
# PATCH-FIX-UPSTREAM 0001-ofp-print-Don-t-abort-on-unknown-reason-in-role-stat.patch
# Upstream fix (present in 2.7 branch) to fix CVE-2017-9263
# See https://nvd.nist.gov/vuln/detail/CVE-2017-9263
Patch2:         0001-ofp-print-Don-t-abort-on-unknown-reason-in-role-stat.patch
# PATCH-FIX-UPSTREAM 0001-ofp-util-Check-length-of-buckets-in-ofputil_pull_ofp.patch
# Upstream fix (present in 2.7 branch) to fix CVE-2017-9265
# See https://nvd.nist.gov/vuln/detail/CVE-2017-9265
Patch3:         0001-ofp-util-Check-length-of-buckets-in-ofputil_pull_ofp.patch
# PATCH-FIX-UPSTREAM 0001-ofp-util-Fix-memory-leaks-on-error-cases-in-ofputil_.patch
# Upstream fix (present in 2.7 branch) to fix CVE-2017-14970
# See https://nvd.nist.gov/vuln/detail/CVE-2017-14970
Patch4:         0001-ofp-util-Fix-memory-leaks-on-error-cases-in-ofputil_.patch
# PATCH-FIX-UPSTREAM 0001-ofp-util-Fix-memory-leaks-when-parsing-OF1.5-group-p.patch
# Upstream fix (present in 2.7 branch) to fix CVE-2017-14970
# See https://nvd.nist.gov/vuln/detail/CVE-2017-14970
Patch5:         0001-ofp-util-Fix-memory-leaks-when-parsing-OF1.5-group-p.patch
Patch99:        0001-utilities-Add-script-to-support-DPDK-option-migratio.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  graphviz
BuildRequires:  libcap-ng-devel
BuildRequires:  libopenssl-devel
BuildRequires:  libtool
BuildRequires:  make
BuildRequires:  pkgconfig
BuildRequires:  python-devel
BuildRequires:  python-six
BuildRequires:  python-xml
BuildRequires:  pkgconfig(openssl)
Requires:       logrotate
Requires:       modutils
Requires:       python
# ovs-ctl / ovs-pki use /usr/bin/uuidgen:
Requires:       util-linux
Requires(post): %fillup_prereq
Suggests:       logrotate
Provides:       openvswitch-common = %{version}
Obsoletes:      openvswitch-common < %{version}
Provides:       openvswitch-controller = %{version}
Obsoletes:      openvswitch-controller < %{version}
# openvswitch-switch has been merged to the main package
# so we need to provide a migration path
Provides:       %{name}-dpdk = %{version}
Provides:       %{name}-dpdk-switch = %{version}
Provides:       %{name}-switch = %{version}
Obsoletes:      %{name}-dpdk < %{version}
Obsoletes:      %{name}-dpdk-switch < %{version}
Obsoletes:      %{name}-switch < %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{?systemd_requires}
%py_requires
# Needed by the testsuite
%if %{with check}
BuildRequires:  procps
%endif
%if %{with kmp}
Suggests:       openvswitch-kmp
%endif
%if %{with dpdk}
# We need to be a bit strict with the dpdk version since
# it's very possible for DPDK to change it's API between
# releases. This version currently requires >=16.07 but not
# 17.XX
BuildRequires:  dpdk-devel >= 16.11
BuildRequires:  libnuma-devel
BuildRequires:  libpcap-devel
%endif

%description
Open vSwitch is a production quality, multilayer virtual switch licensed under
the open source Apache 2.0 license. It is designed to enable massive network automation
through programmatic extension, while still supporting standard management interfaces
and protocols (e.g. NetFlow, sFlow, RSPAN, ERSPAN, CLI, LACP, 802.1ag). In addition,
it is designed to support distribution across multiple physical servers similar to
VMware’s vNetwork distributed vswitch or Cisco’s Nexus 1000V.

%if %{with kmp}
%package kmp
Summary:        Open vSwitch kernel modules
License:        GPL-2.0+
Group:          System/Kernel
BuildRequires:  %{kernel_module_package_buildreqs}
%suse_kernel_module_package -p %{_sourcedir}/preamble ec2 xenpae vmi um

%description kmp
Kernel modules supporting the openvswitch datapath.
%endif

%package devel
Summary:        Open vSwitch Devel Libraries
License:        Apache-2.0
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Provides:       %{name}-dpdk-devel = %{version}
Obsoletes:      %{name}-dpdk-devel < %{version}

%description devel
Devel libraries and headers for Open vSwitch.

%package ovn-central
Summary:        Open vSwitch - Open Virtual Network support
License:        Apache-2.0
Group:          Productivity/Networking/System
Requires:       %{name} = %{version}
Requires:       %{name}-ovn-common
# openvswitch-ovn has been split into openvswitch-ovn-{central,common,docker,host,vtep}
Provides:       %{name}-dpdk-ovn:%{_bindir}/ovn-northd
Provides:       %{name}-ovn:%{_bindir}/ovn-northd

%description ovn-central
OVN, the Open Virtual Network, is a system to support virtual network
abstraction.  OVN complements the existing capabilities of OVS to add
native support for virtual network abstractions, such as virtual L2 and L3
overlays and security groups.

%package ovn-host
Summary:        Open vSwitch - Open Virtual Network support
License:        Apache-2.0
Group:          Productivity/Networking/System
Requires:       %{name} = %{version}
Requires:       %{name}-ovn-common
# openvswitch-ovn has been split into openvswitch-ovn-{central,common,docker,host,vtep}
Provides:       %{name}-dpdk-ovn:%{_bindir}/ovn-controller
Provides:       %{name}-ovn:%{_bindir}/ovn-controller

%description ovn-host
OVN, the Open Virtual Network, is a system to support virtual network
abstraction.  OVN complements the existing capabilities of OVS to add
native support for virtual network abstractions, such as virtual L2 and L3
overlays and security groups.

%package ovn-vtep
Summary:        Open vSwitch - Open Virtual Network support
License:        Apache-2.0
Group:          Productivity/Networking/System
Requires:       %{name} = %{version}
Requires:       %{name}-ovn-common
# openvswitch-ovn has been split into openvswitch-ovn-{central,common,docker,host,vtep}
Provides:       %{name}-dpdk-ovn:%{_bindir}/ovn-controller-vtep
Provides:       %{name}-ovn:%{_bindir}/ovn-controller-vtep

%description ovn-vtep
OVN vtep controller

%package ovn-common
Summary:        Open vSwitch - Open Virtual Network support
License:        Apache-2.0
Group:          Productivity/Networking/System
Requires:       %{name} = %{version}
# openvswitch-ovn has been split into openvswitch-ovn-{central,common,docker,host,vtep}
Provides:       %{name}-dpdk-ovn = %{version}
Provides:       %{name}-ovn = %{version}
Obsoletes:      %{name}-dpdk-ovn < %{version}
Obsoletes:      %{name}-ovn < %{version}

%description ovn-common
Utilities that are used to diagnose and manage the OVN components.

%package ovn-docker
Summary:        Open vSwitch - Open Virtual Network support
License:        Apache-2.0
Group:          Productivity/Networking/System
Requires:       %{name} = %{version}
Requires:       %{name}-ovn-common = %{version}
Requires:       python-openvswitch = %{version}
# openvswitch-ovn has been split into openvswitch-ovn-{central,common,docker,host,vtep}
Provides:       %{name}-dpdk-ovn:%{_bindir}/ovn-docker-overlay-driver
Provides:       %{name}-ovn:%{_bindir}/ovn-docker-overlay-driver

%description ovn-docker
Docker network plugins for OVN.

%package pki
Summary:        Open vSwitch public key infrastructure dependency package
License:        Apache-2.0
Group:          Productivity/Networking/System
Requires:       %{name} = %{version}
Provides:       %{name}-dpdk-pki = %{version}
Obsoletes:      %{name}-dpdk-pki < %{version}

%description pki
openvswitch-pki provides PKI (public key infrastructure) support for
Open vSwitch switches and controllers, reducing the risk of
man-in-the-middle attacks on the Open vSwitch network infrastructure.

Open vSwitch is a full-featured software-based Ethernet switch.

%package vtep
Summary:        Open vSwitch VTEP emulator
License:        Apache-2.0
Group:          Productivity/Networking/System
Requires:       %{name} = %{version}
Requires:       %{name}-switch = %{version}
# Since openvswitch/scripts/ovs-vtep requires various ovs python modules.
Requires:       python-openvswitch = %{version}
Provides:       %{name}-dpdk-vtep = %{version}
Obsoletes:      %{name}-dpdk-vtep < %{version}

%description vtep
A VTEP (VXLAN Tunnel EndPoint) emulator that uses Open vSwitch for
forwarding.

Open vSwitch is a full-featured software-based Ethernet switch.

%package -n python-openvswitch
Summary:        Python bindings for Open vSwitch
License:        Python-2.0
Group:          Productivity/Networking/System
Requires:       openvswitch-common = %{version}
Requires:       python
Requires:       python-six

%description -n python-openvswitch
This package contains the full Python bindings for Open vSwitch database.

%package -n python-openvswitch-test
Summary:        Python bindings for Open vSwitch
License:        Python-2.0
Group:          Productivity/Networking/System
Requires:       openvswitch-common = %{version}
Requires:       python
Requires:       python-openvswitch = %{version}
Requires:       python-twisted

%description -n python-openvswitch-test
This package contains the full Python bindings for Open vSwitch database.

%package test
Summary:        Open vSwitch test package
License:        Apache-2.0
Group:          Productivity/Networking/System
Requires:       %{name} = %{version}
Requires:       python
Requires:       python-argparse
Requires:       python-openvswitch-test = %{version}
Requires:       python-twisted
Provides:       %{name}-dpdk-test = %{version}
Obsoletes:      %{name}-dpdk-test < %{version}

%description test
This package contains utilities that are useful to diagnose
performance and connectivity issues in Open vSwitch setup.

Open vSwitch is a full-featured software-based Ethernet switch.

%prep
%setup -q -n openvswitch-%{version}
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch99 -p1

%build
set -- * .travis* .mailmap
mkdir source
mv "$@" source/
mkdir obj

pushd source
# only call boot.sh for distros with autoconf >= 2.64
bash -x boot.sh
popd
%if %{with kmp}
export EXTRA_CFLAGS='-DVERSION=\"%{version}\"'
for flavor in %{flavors_to_build}; do
    rm -rf obj/$flavor
    cp -r source obj/$flavor
    cp -a %{SOURCE89} obj/$flavor/datapath/linux/Module.supported
    pushd obj/$flavor
    %configure \
	--with-logdir=%{_localstatedir}/log/openvswitch \
	--with-linux=%{_prefix}/src/linux-obj/%{_target_cpu}/$flavor \
	--with-linux-source=%{_prefix}/src/linux
    cd datapath/linux
    make %{?_smp_mflags}
    popd
done
%endif

pushd source

%if %{with dpdk}
dpdk_opt="--with-dpdk"
%endif

%configure \
        --disable-static \
        --enable-libcapng \
        --enable-shared \
        --enable-ssl \
        ${dpdk_opt} \
        --with-logdir=%{_localstatedir}/log/openvswitch
make %{?_smp_mflags}
popd

%check
%if %{with check}
pushd source
# Recheck tests before we declare them broken. If that fails, dump
# the log and exit. >2.5.0 uses the RECHECK env variable so this
# needs to be taken into consideration for future releases.
if make check TESTSUITEFLAGS="%{?_smp_mflags}" ||
   make check TESTSUITEFLAGS='--recheck'; then :;
else
    cat tests/testsuite.log
    exit 1
fi
popd
%endif

%install
%if %{with kmp}
export NO_BRP_STALE_LINK_ERROR=yes
export INSTALL_MOD_PATH=%{buildroot}
export INSTALL_MOD_DIR=updates
export BRP_PESIGN_FILES="*.ko /lib/firmware"
for flavor in %{flavors_to_build}; do
    pushd obj/$flavor/datapath/linux
    make -C %{_prefix}/src/linux-obj/%{_target_cpu}/$flavor modules_install M=$PWD
    popd
done
%endif

pushd source

%make_install

for service in openvswitch ovn-controller ovn-controller-vtep \
    ovn-northd ovsdb-server ovs-vswitchd; do
        install -D -m 644 rhel/usr_lib_systemd_system_${service}.service \
        %{buildroot}%{_unitdir}/${service}.service
        ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rc${service}
done

install -D -m 644 rhel/usr_share_openvswitch_scripts_systemd_sysconfig.template \
        %{buildroot}%{_localstatedir}/adm/fillup-templates/sysconfig.openvswitch

install -d -m 755 %{buildroot}%{_sysconfdir}/logrotate.d
install -d -m 755 %{buildroot}%{_localstatedir}/log/openvswitch

install -m 644 rhel/etc_logrotate.d_openvswitch \
         %{buildroot}%{_sysconfdir}/logrotate.d/openvswitch
install -d -m 755 %{buildroot}%{_sysconfdir}/profile.d

install -m 644 vswitchd/vswitch.ovsschema \
         %{buildroot}%{_datadir}/openvswitch/vswitch.ovsschema

# firewalld
install -d %{buildroot}%{_prefix}/lib/firewalld/services/
install -p -m 0644 rhel/usr_lib_firewalld_services_ovn-central-firewall-service.xml \
        %{buildroot}%{_prefix}/lib/firewalld/services/ovn-central-firewall-service.xml
install -p -m 0644 rhel/usr_lib_firewalld_services_ovn-host-firewall-service.xml \
        %{buildroot}%{_prefix}/lib/firewalld/services/ovn-host-firewall-service.xml

# Copy documentation. The git archive builds also contain non rst files
# to make sure we clean everything we don't need.
find Documentation/ -type f ! -name '*.rst' -delete
find Documentation/ -type d -empty -delete
pushd Documentation/
mkdir -p %{buildroot}%{_docdir}/%{name}
cp -r * %{buildroot}%{_docdir}/%{name}
popd

# DPDK migration script
install -m 755 utilities/ovs-dpdk-migrate-2.6.sh %{buildroot}/%{_datadir}/openvswitch/scripts/

popd

mkdir -p %{buildroot}%{py_sitedir}
mv %{buildroot}%{_datadir}/openvswitch/python/* %{buildroot}%{py_sitedir}
rmdir %{buildroot}%{_datadir}/openvswitch/python

find %{buildroot} -type f -name "*.la" -delete -print

%fdupes %{buildroot}%{py_sitedir}

%post
/sbin/ldconfig
if grep -q ^DPDK_OPTIONS= %{_sysconfdir}/sysconfig/openvswitch &> /dev/null; then
    cat >> %{_localstatedir}/adm/update-messages/%{name}-%{version}-%{release} << EOF
    WARNING! DPDK options are now part of the Open vSwitch database. Please see
    https://github.com/openvswitch/ovs/blob/branch-2.7/Documentation/intro/install/dpdk.rst

    The Open vSwitch systemd service will try to migrate your %{_sysconfdir}/sysconfig/openvswitch
    DPDK settings to the OvS database the next time it's restarted but you should check the result
    using 'ovs-vsctl list Open_vSwitch' or something similar.

    Please remember to remove the DPDK_OPTIONS variable from %{_sysconfdir}/sysconfig/openvswitch
    to avoid seeing this warning again.
EOF
fi
%service_add_post ovsdb-server.service
%service_add_post ovs-vswitchd.service
%service_add_post openvswitch.service
%{fillup_only -n openvswitch}

%postun
/sbin/ldconfig
# Do not restart the openvswitch service on package updates.
# Restarting the service may break the existing network state.
# For example, openflow rules are not automatically re-installed
# after an OvS update if no SDN controller is used. Moreover, restaring
# the OvS can break remote administration during the update so let the
# admin decide when it's the best time for an OvS restart.
# 5771f476573445710834234a6a9f7bd999a027e7 ("fedora: do not restart the service on a pkg upgrade")
export DISABLE_RESTART_ON_UPDATE=yes
%service_del_postun ovsdb-server.service
%service_del_postun ovs-vswitchd.service
%service_del_postun openvswitch.service

%pre
%service_add_pre ovsdb-server.service
%service_add_pre ovs-vswitchd.service
%service_add_pre openvswitch.service

%preun
# This prevents networking breakages on package removals.
export DISABLE_STOP_ON_REMOVAL=yes
%service_del_preun ovsdb-server.service
%service_del_preun ovs-vswitchd.service
%service_del_preun openvswitch.service

%pre ovn-central
%service_add_pre ovn-northd.service

%pre ovn-host
%service_add_pre ovn-controller.service

%pre ovn-vtep
%service_add_pre ovn-controller-vtep.service

%post ovn-central
%service_add_post ovn-northd.service

%post ovn-host
%service_add_post ovn-controller.service

%post ovn-vtep
%service_add_post ovn-controller-vtep.service

%preun ovn-central
%service_del_preun ovn-northd.service

%preun ovn-host
%service_del_preun ovn-controller.service

%preun ovn-vtep
%service_del_preun ovn-controller-vtep.service

%postun ovn-central
%service_del_postun ovn-northd.service

%post ovn-common -p /sbin/ldconfig
%postun ovn-common -p /sbin/ldconfig

%postun ovn-host
%service_del_postun ovn-controller.service

%postun ovn-vtep
%service_del_postun ovn-controller-vtep.service

%preun test
%stop_on_removal openvswitch-testcontroller

%postun test
%restart_on_update openvswitch-testcontroller

%post vtep -p /sbin/ldconfig
%postun vtep -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc source/AUTHORS.rst
%doc source/CONTRIBUTING.rst
%doc source/COPYING
%doc source/NEWS
%doc source/NOTICE
%doc source/README.rst
%{_docdir}/%{name}/
%{_bindir}/ovs-appctl
%{_bindir}/ovs-docker
%{_bindir}/ovs-dpctl
%{_bindir}/ovs-dpctl-top
%{_bindir}/ovs-ofctl
%{_bindir}/ovs-parse-backtrace
%{_bindir}/ovs-vsctl
%{_bindir}/ovsdb-client
%{_bindir}/ovsdb-tool
%{_sbindir}/ovs-bugtool
%{_sbindir}/ovs-vlan-bug-workaround
%{_sbindir}/ovs-vswitchd
%{_sbindir}/ovsdb-server
%dir %{_datadir}/openvswitch
%dir %{_datadir}/openvswitch/scripts
%{_datadir}/openvswitch/bugtool-plugins
%{_datadir}/openvswitch/scripts/ovs-bugtool-*
%{_datadir}/openvswitch/scripts/ovs-check-dead-ifs
%{_datadir}/openvswitch/scripts/ovs-ctl
%{_datadir}/openvswitch/scripts/ovs-lib
%{_datadir}/openvswitch/scripts/ovs-save
%{_datadir}/openvswitch/scripts/ovs-dpdk-migrate-2.6.sh
%{_datadir}/openvswitch/vswitch.ovsschema
%{_libdir}/libofproto-2.so.*
%{_libdir}/libopenvswitch-2.so.*
%{_libdir}/libovsdb-2.so.*
%{_libdir}/libsflow-2.so.*
%{_mandir}/man1/ovsdb-client.1%{ext_man}
%{_mandir}/man1/ovsdb-server.1%{ext_man}
%{_mandir}/man1/ovsdb-tool.1%{ext_man}
%{_mandir}/man5/ovs-vswitchd.conf.db.5%{ext_man}
%{_mandir}/man7/ovs-fields.7%{ext_man}
%{_mandir}/man8/ovs-appctl.8%{ext_man}
%{_mandir}/man8/ovs-bugtool.8%{ext_man}
%{_mandir}/man8/ovs-ctl.8%{ext_man}
%{_mandir}/man8/ovs-dpctl-top.8%{ext_man}
%{_mandir}/man8/ovs-dpctl.8%{ext_man}
%{_mandir}/man8/ovs-ofctl.8%{ext_man}
%{_mandir}/man8/ovs-vlan-bug-workaround.8%{ext_man}
%{_mandir}/man8/ovs-parse-backtrace.8%{ext_man}
%{_mandir}/man8/ovs-vsctl.8%{ext_man}
%{_mandir}/man8/ovs-vswitchd.8%{ext_man}
%{_sysconfdir}/bash_completion.d/ovs-appctl-bashcomp.bash
%{_sysconfdir}/bash_completion.d/ovs-vsctl-bashcomp.bash
%dir %{_sysconfdir}/openvswitch
%config %ghost %{_sysconfdir}/openvswitch/conf.db
%config %ghost %{_sysconfdir}/openvswitch/system-id.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/openvswitch
%{_sbindir}/rcovsdb-server
%{_sbindir}/rcovs-vswitchd
%{_sbindir}/rcopenvswitch
%{_unitdir}/openvswitch.service
%{_unitdir}/ovs-vswitchd.service
%{_unitdir}/ovsdb-server.service
%{_localstatedir}/adm/fillup-templates/sysconfig.openvswitch
%dir %{_localstatedir}/log/openvswitch

%files pki
%defattr(-,root,root)
%{_mandir}/man8/ovs-pki.8%{ext_man}
%{_bindir}/ovs-pki

%files vtep
%defattr(-,root,root)
%{_bindir}/vtep-ctl
%{_mandir}/man5/vtep.5%{ext_man}
%{_mandir}/man8/vtep-ctl.8%{ext_man}
%{_datadir}/openvswitch/scripts/ovs-vtep
%{_datadir}/openvswitch/vtep.ovsschema
%{_libdir}/libvtep-2.so.*

%files -n python-openvswitch
%defattr(-,root,root)
%{py_sitedir}/ovs/

%files -n python-openvswitch-test
%defattr(-,root,root)
%{py_sitedir}/ovstest/

%files ovn-docker
%defattr(-,root,root)
%{_bindir}/ovn-docker-overlay-driver
%{_bindir}/ovn-docker-underlay-driver

%files ovn-common
%defattr(-,root,root)
%{_bindir}/ovn-nbctl
%{_bindir}/ovn-sbctl
%{_bindir}/ovn-trace
%{_datadir}/openvswitch/scripts/ovn-ctl
%{_datadir}/openvswitch/scripts/ovndb-servers.ocf
%{_datadir}/openvswitch/scripts/ovn-bugtool-nbctl-show
%{_datadir}/openvswitch/scripts/ovn-bugtool-sbctl-lflow-list
%{_datadir}/openvswitch/scripts/ovn-bugtool-sbctl-show
%{_libdir}/libovn-2.so.*
%{_mandir}/man5/ovn-nb.5%{ext_man}
%{_mandir}/man5/ovn-sb.5%{ext_man}
%{_mandir}/man7/ovn-architecture.7%{ext_man}
%{_mandir}/man8/ovn-ctl.8%{ext_man}
%{_mandir}/man8/ovn-nbctl.8%{ext_man}
%{_mandir}/man8/ovn-trace.8%{ext_man}
%{_mandir}/man8/ovn-sbctl.8%{ext_man}

%files ovn-central
%defattr(-,root,root)
%dir %{_libexecdir}/firewalld
%dir %{_libexecdir}/firewalld/services
%{_bindir}/ovn-northd
%{_mandir}/man8/ovn-northd.8%{ext_man}
%config %{_datadir}/openvswitch/ovn-nb.ovsschema
%config %{_datadir}/openvswitch/ovn-sb.ovsschema
%{_unitdir}/ovn-northd.service
%{_sbindir}/rcovn-northd
%{_prefix}/lib/firewalld/services/ovn-central-firewall-service.xml

%files ovn-host
%defattr(-,root,root)
%dir %{_libexecdir}/firewalld
%dir %{_libexecdir}/firewalld/services
%{_bindir}/ovn-controller
%{_mandir}/man8/ovn-controller.8%{ext_man}
%{_unitdir}/ovn-controller.service
%{_sbindir}/rcovn-controller
%{_prefix}/lib/firewalld/services/ovn-host-firewall-service.xml

%files ovn-vtep
%defattr(-,root,root)
%{_bindir}/ovn-controller-vtep
%{_mandir}/man8/ovn-controller-vtep.8%{ext_man}
%{_unitdir}/ovn-controller-vtep.service
%{_sbindir}/rcovn-controller-vtep

%files test
%defattr(-,root,root)
%{_bindir}/ovs-l3ping
%{_bindir}/ovs-pcap
%{_bindir}/ovs-test
%{_bindir}/ovs-testcontroller
%{_bindir}/ovs-tcpdump
%{_bindir}/ovs-tcpundump
%{_bindir}/ovs-vlan-test
%{_mandir}/man1/ovs-pcap.1%{ext_man}
%{_mandir}/man1/ovs-tcpundump.1%{ext_man}
%{_mandir}/man8/ovs-l3ping.8%{ext_man}
%{_mandir}/man8/ovs-tcpdump.8%{ext_man}
%{_mandir}/man8/ovs-test.8%{ext_man}
%{_mandir}/man8/ovs-testcontroller.8%{ext_man}
%{_mandir}/man8/ovs-vlan-test.8%{ext_man}

%files devel
%defattr(-,root,root)
%{_libdir}/libofproto.so
%{_libdir}/libopenvswitch.so
%{_libdir}/libovn.so
%{_libdir}/libovsdb.so
%{_libdir}/libsflow.so
%{_libdir}/libvtep.so
%{_includedir}/openflow/
%{_includedir}/ovn/
%{_includedir}/openvswitch/
%{_libdir}/pkgconfig/*.pc

%changelog
* Wed Nov 29 2017 mchandras@suse.de
- Add upstream patches to fix memory leaks (cve-2017-14970) (bsc#1061310)
  * 0001-ofp-util-Fix-memory-leaks-when-parsing-OF1.5-group-p.patch
  * 0001-ofp-util-Fix-memory-leaks-on-error-cases-in-ofputil_.patch
* Wed Sep  6 2017 mchandras@suse.de
- Fix 'Provides' version constraints for old openvswitch-dpdk package.
  Also fix the logrotate file to be named after the package name instead
  of the obsoleted openvswitch-switch one (bsc#1057357)
* Wed Aug 16 2017 mchandras@suse.de
- Add missing post/postun scriptlets for ovn-common subpackage (bsc#1054094)
  The ovn-common subpackage contains the libovn library so it needs to call
  ldconfig after installation or removal.
* Thu Jul 27 2017 mchandras@suse.de
- Do not restart the ovs-vswitchd and ovsdb-server services
  on package updates (bsc#1002734)
- Do not restart the ovs-vswitchd, ovsdb-server and openvswitch
  services on package removals. This facilitates potential future
  package moves but also preserves connectivity when the package is
  removed (bsc#1050896)
* Wed Jul 19 2017 mchandras@suse.de
- Add upstream patches to fix two security vulnerabilities
  * 0001-ofp-print-Don-t-abort-on-unknown-reason-in-role-stat.patch (cve-2017-9263) (bsc#1041470)
  * 0001-ofp-util-Check-length-of-buckets-in-ofputil_pull_ofp.patch (cve-2017-9265) (bsc#1041447)
* Sat May 27 2017 mchandras@suse.de
- Install firewalld OVN files with chmod 644 instead of 755 (4a54614120ea)
- Use python-six instead of python2-six dependency to cover distributions
  which are not using the python-singlespec packaging specification yet (bsc#1041110)
- Add upstream patch to fix a buffer overread vulnerability (cve-2017-9214) (bsc#1040543)
  * 0001-ofp-util-Fix-buffer-overread-in-ofputil_pull_queue_g.patch
* Tue Feb 28 2017 mchandras@suse.de
- Version bump to 2.7.0 (fate#321541). Some of the changes are:
  * Utilities and daemons that support SSL now allow protocols and
    ciphers to be configured with --ssl-protocols and --ssl-ciphers.
  * OVN:
  - QoS is now implemented via egress shaping rather than ingress policing.
  - DSCP marking is now supported, via the new northbound QoS table.
  - IPAM now supports fixed MAC addresses.
  - Support for source IP address based routing.
  - ovn-trace:
  * New --ovs option to also print OpenFlow flows.
  * put_dhcp_opts and put_dhcp_optsv6 actions may now be traced.
  - Support for managing SSL and remote connection configuration in
    northbound and southbound databases.
  * Fixed regression in table stats maintenance introduced in OVS
    2.3.0, wherein the number of OpenFlow table hits and misses was
    not accurate.
  * OpenFlow:
  - OFPT_PACKET_OUT messages are now supported in bundles.
  - A new "selection_method=dp_hash" type for OpenFlow select group
    bucket selection that uses the datapath computed 5-tuple hash
    without making datapath flows match the 5-tuple fields, which
    is useful for more efficient load balancing, for example.  This
    uses the Netronome extension to OpenFlow 1.5+ that allows
    control over the OpenFlow select groups selection method.  See
    "selection_method" and related options in ovs-ofctl(8) for
    details.
  - The "sample" action now supports "ingress" and "egress" options.
  - The "ct" action now supports the TFTP ALG where support is available.
  - New actions "clone" and "ct_clear".
  * ovs-ofctl:
  - 'bundle' command now supports packet-out messages.
  - New syntax for 'ovs-ofctl packet-out' command, which uses the
    same string parser as the 'bundle' command.  The old 'packet-out'
    syntax is deprecated and will be removed in a later OVS
    release.
  - New unixctl "ofctl/packet-out" command, which can be used to
    instruct a flow monitor to issue OpenFlow packet-out messages.
  * ovsdb-server:
  - Remote connections can now be made read-only (see ovsdb-server(1)).
  * DPDK:
  - Support for DPDK v16.11.
  - Support for rx checksum offload. Refer DPDK HOWTO for details.
  - Port Hotplug is now supported.
  - DPDK physical ports can now have arbitrary names. The PCI address of
    the device must be set using the 'dpdk-devargs' option. Compatibility
    with the old dpdk<portid> naming scheme is broken, and as such a
    device will not be available for use until a valid dpdk-devargs is
    specified.
  - Virtual DPDK Poll Mode Driver (vdev PMD) support.
  * For the complete list of changes, please see:
  - http://openvswitch.org/releases/NEWS-2.7.0
- Add patch to fix DPDK configuration migration for < 2.6 installations
  * 0001-utilities-Add-script-to-support-DPDK-option-migratio.patch
- Rework spec file
  * Enable DPDK by default and drop openvswitch-dpdk* packages. DPDK is only
    enabled on supported architectures though.
  - Remove openvswitch-dpdk.changes
  - Remove openvswitch-dpdk.spec
  - Remove pre_checkin.sh
  * Merge openvswitch and openvswitch-switch into a single package since there
    was no compelling reason to keep the switch functionality in a separate
    subpackage.
  * Split OVN package to ovn-common, ovn-central, ovn-docker, ovn-host and
    ovn-controller similar to the Debian and RedHat packages.
* Fri Nov 25 2016 mchandras@suse.de
- Relax the DPDK dependency a bit so we can support stable and
  possibly new minor releases as well.
* Mon Nov 21 2016 mchandras@suse.de
- Do not restart the openvswitch service after a package update.
  Restarting the systemd service may break connectivity so let the
  user decide when it is the best time for such an action. (bsc#1002734)
* Thu Nov  3 2016 mchandras@suse.de
- Version bump to 2.6.1. Some of the changes are:
  * ovn: Do not reply to ARP or ND NS for a VM's own IP address.
  * ovs-ofctl: Tolerate differences in IPv6 formatting.
  * netdev-linux: double tagged packets should use 0x88a8
  * expr: Fix abort when simplifying "x != 0/0".
  * dpif-netdev: Fix crash in dpif_netdev_execute().
  * ovn-controller: Container can have connection to a hosting VM.
  * stream-ssl: Fix memory leak on error path.
  * Other bug fixes.
* Mon Oct  3 2016 mchandras@suse.de
- Version bump to 2.6.0. Some of the changes are:
  * First supported release of OVN.  See ovn-architecture(7) for more
    details.
  * ovsdb-server:
  - New "monitor_cond" "monitor_cond_update" and "update2" extensions to
    RFC 7047.
  * OpenFlow:
  - OpenFlow 1.3+ bundles now expire after 10 seconds since the
    last time the bundle was either opened, modified, or closed.
  - OpenFlow 1.3 Extension 230, adding OpenFlow Bundles support, is
    now implemented.
  - OpenFlow 1.3+ bundles are now supported for group mods as well as
    flow mods and port mods.  Both 'atomic' and 'ordered' bundle
    flags are supported for group mods as well as flow mods.
  - Internal OpenFlow rule representation for load and set-field
    actions is now much more memory efficient.  For a complex flow
    table this can reduce rule memory consumption by 40%%.
  - Bundles are now much more memory efficient than in OVS 2.5.
    Together with memory efficiency improvements in OpenFlow rule
    representation, the peak OVS resident memory use during a
    bundle commit for large complex set of flow mods can be only
    25%% of that in OVS 2.5 (4x lower).
  - OpenFlow 1.1+ OFPT_QUEUE_GET_CONFIG_REQUEST now supports OFPP_ANY.
  - OpenFlow 1.4+ OFPMP_QUEUE_DESC is now supported.
  - OpenFlow 1.4+ OFPT_TABLE_STATUS is now supported.
  - New property-based packet-in message format NXT_PACKET_IN2 with support
    for arbitrary user-provided data and for serializing flow table
    traversal into a continuation for later resumption.
  - New extension message NXT_SET_ASYNC_CONFIG2 to allow OpenFlow 1.4-like
    control over asynchronous messages in earlier versions of OpenFlow.
  - [...]
  - For a complete list of changes, please see
    http://openvswitch.org/releases/NEWS-2.6.0
- Remove obsolete patches and files
  * 0001-Remove-broken-pipe-warning-logs-from-ovsdb-server.lo.patch
  * 0001-ovs-ctl-Add-new-DPDK_OPTIONS-environment-variable.patch
  * openvswitch-2.5.0-detect-dpdk-installation.patch
  * openvswitch-switch.logrotate
  * openvswitch.service
* Wed Sep 28 2016 mchandras@suse.de
- New upstream bugfix release 2.5.1 (bsc#1001657)
  * DPDK:
  - New appctl command 'dpif-netdev/pmd-rxq-show' to check the port/rxq
    assignment.
  - Type of log messages from PMD threads changed from INFO to DBG.
  * ovs-pki: Changed message digest algorithm from SHA-1 to SHA-512 because
    SHA-1 is no longer secure and some operating systems have started to
    disable it in OpenSSL.
  * Bug fixes
* Tue Sep  6 2016 mchandras@suse.de
- Add new DPDK_OPTIONS environment variable to hold the dpdk
  vswitchd options so that the systemd unit files can be used to
  launch an ovs-vswitcd DPDK capable instance instead of doing
  it manually. (bsc#987265)
  * 0001-ovs-ctl-Add-new-DPDK_OPTIONS-environment-variable.patch
* Sun Aug 14 2016 ro@suse.de
- enable openvswitch-dpdk on aarch64 since dpdk
  builds on aarch64 now
* Sun Aug  7 2016 ro@suse.de
- remove aarch from openvswitch-dpdk until we have a dpdk
  that builds for aarch64
* Tue Jul 12 2016 mchandras@suse.de
- Add missing licenses (bsc#988513)
- Misc spec file cleanups highlighted by the spec-cleaner tool.
- Allow aarch64 builds for openvswitch-dpdk
* Mon Jul  4 2016 mchandras@suse.de
- Allow the OvS daemon to run as non-root (bsc#987545)
- Add missing 'Conflicts' statements to all the subpackages as
  required by the Factory review tools.
* Wed Jun 29 2016 mchandras@suse.de
- Remove the ?_with_dpdk macro usage since this is not being set
  without explicitly passing --with/--without during an OBS build.
  This reverts back to using the %%{with dpdk} style which is set
  automatically based on %%bcond_with* macros (bsc#989335).
* Tue Jun 28 2016 mchandras@suse.de
- Fix subpackage dependencies to not require the non-existent python
  DPDK subpackages (bsc#986835). We do not provide DPDK versions of
  the python bindings so nothing should depend on these subpackages.
* Wed Jun 22 2016 jengelh@inai.de
- Update rpm groups, acronym forms.
* Tue Jun 21 2016 mchandras@suse.de
- Multiple fixes for the openvswitch-dpdk package (bsc#985878)
  * Rename main package name to openvswitch-dpdk
  * Do not build the python and kmp packages since they do not
    depend on the DPDK capabilities
  * Remove the open_virtual_switch capability. The
    openvswitch-common will be used by reverse dependencies to
    require either of the OvS packages.
  * Provide virtual capabilities for all DPDK subpackages.
  * Fix the dependencies in the python package to require either
    of the OvS packages.
  * Suggest the kmp package only if it's actually provided.
  * Small cleanups.
* Fri May 27 2016 mchandras@suse.de
- Add %%check directive to run the openvswitch testsuite on demand.
  The openvswitch contains hundreds of tests covering simple and
  complex openvswitch configuration so it's beneficial to run them
  during package builds. However, running the testsuite is not enabled
  by default. Also add the following upstream patch:
  * 0001-Remove-broken-pipe-warning-logs-from-ovsdb-server.lo.patch
* Thu May 26 2016 mchandras@suse.de
- Build a DPDK-enabled Open vSwitch (fate#319170)
  * Apply the following changes to the openvswitch.spec file
  - Add support for building with DPDK capabilities
  - Add conflicts between the two packages.
  - Add new 'open_virtual_switch-*' capabilities for openvswitch,
    openvswitch-switch, openvswitch-test packages which can be used
    by reverse dependencies to select between the two openvswitch
    implementations.
  * Add pre_checkin.sh to generate the openvswitch_dpdk.spec file
    based on the openvswitch.spec one.
  * Add upstream openvswitch-2.5.0-detect-dpdk-installation.patch
    patch to detect and link against a DPDK installation.
* Mon May 23 2016 jengelh@inai.de
- Keep %%prep small for speedier `quilt setup`. Kill __DATE__ from
  source. Drop all .la files that are in %%_libdir.
* Fri May 20 2016 mchandras@suse.de
- Add missing %%dir directive for /var/log/openvswitch
* Thu May 19 2016 dmueller@suse.com
- remove aarch64 conditional, no longer needed
* Thu May  5 2016 mchandras@suse.de
- Multiple spec file and package fixes.
  * Drop obsolete log-check-module-loop.patch patch.
  * Drop conditional code for older openSUSE releases. This also removes
    all of the sysvinit files which were pulled in when the package was
    originally developed.
  * Drop support for building the GUI. The GUI code has been removed in
    7868fbc6c97c2 ("ovsdbmonitor: Remove.") upstream commit and it does
    not exist since v2.2.0 so drop the code in the spec file.
  * Use the upstream systemd service files for the OVN components instead
    of maintaining our own downstream.
  * Drop the unofficial ipsec support. It hasn't been enabled in years.
  * Drop support for building the upstream kernel module since it's being
    shipped with the kernel package in latest releases. Restore the
    %%bcond_with kmp to make it easier to build the external kernel module
    if needed.
  * Fix some suse-missing-rclink rpmlint warnings for the ovn subpackage
  * Base our service unit to the upstream one.
  * Stop silently enabling the GRE protocol in iptables by default.
  * Install the upstream sysconfig file to pass more information to the
    openvswitch service unit.
  * Use make install instead of %%makeinstall
  * Drop brcompat leftovers.
  * spec-cleaner fixes
* Fri Apr  1 2016 dmueller@suse.com
- address dimstars concerns
* Tue Mar 22 2016 mchandras@suse.de
- Prevent systemd from autogenerating a service file for
  openvswitch-switch which conflicts with the opevswitch
  one. (bsc#966762)
* Fri Mar 18 2016 kmroz@suse.com
- Add missing %%defattr to ovn files section.
* Tue Mar  8 2016 kmroz@suse.com
- Add additional install requirements for python-openvswitch-test
  package.
* Fri Mar  4 2016 kmroz@suse.com
- Add support for building both 2.4.0 and 2.5.0 from the same spec
  file. Needed to fix SLE11 builds as OVS-2.5.0 no longer supports
  python < 2.7. SLE11 SP3 and SP4 use python 2.6.
- Added: openvswitch-2.4.0.tar.gz
* Thu Mar  3 2016 kmroz@suse.com
- New upstream version 2.5.0 (LTS)
  - Dropped support for Python older than version 2.7.  As a consequence,
    using Open vSwitch 2.5 or later on XenServer 6.5 or earlier (which
    have Python 2.4) requires first installing Python 2.7.
  - OpenFlow:
  * Group chaining (where one OpenFlow group triggers another) is
    now supported.
  * OpenFlow 1.4+ "importance" is now considered for flow eviction.
  * OpenFlow 1.4+ OFPTC_EVICTION is now implemented.
  * OpenFlow 1.4+ OFPTC_VACANCY_EVENTS is now implemented.
  * OpenFlow 1.4+ OFPMP_TABLE_DESC is now implemented.
  * Allow modifying the ICMPv4/ICMPv6 type and code fields.
  * OpenFlow 1.4+ OFPT_SET_ASYNC_CONFIG and OFPT_GET_ASYNC_CONFIG are
    now implemented.
  - ovs-ofctl:
  * New "out_group" keyword for OpenFlow 1.1+ matching on output group.
  - Tunnels:
  * Geneve tunnels can now match and set options and the OAM bit.
  * The nonstandard GRE64 tunnel extension has been dropped.
  - Support Multicast Listener Discovery (MLDv1 and MLDv2).
  - Add 'symmetric_l3l4' and 'symmetric_l3l4+udp' hash functions.
  - sFlow agent now reports tunnel and MPLS structures.
  - New 'check-system-userspace', 'check-kmod' and 'check-kernel' Makefile
    targets to run a new system testsuite.  These tests can be run inside
    a Vagrant box.  See INSTALL.md for details
  - Mark --syslog-target argument as deprecated.  It will be removed in
    the next OVS release.
  - Added --user option to all daemons
  - Add support for connection tracking through the new "ct" action
    and "ct_state"/"ct_zone"/"ct_mark"/"ct_label" match fields.  Only
    available on Linux kernels with the connection tracking module loaded.
  - Add experimental version of OVN.  OVN, the Open Virtual Network, is a
    system to support virtual network abstraction.  OVN complements the
    existing capabilities of OVS to add native support for virtual network
    abstractions, such as virtual L2 and L3 overlays and security groups.
  - RHEL packaging:
  * DPDK ports may now be created via network scripts (see README.RHEL).
  - DPDK:
  * Requires DPDK 2.2
  * Added multiqueue support to vhost-user
  * Note: QEMU 2.5+ required for multiqueue support
  - SELinux:
  * Introduced SELinux policy package.
- New package: openvswitch-ovn
- Removed: openvswitch-2.4.0.tar.gg
- Added: openvswitch-2.5.0.tar.gg
- Added: openvswitch-testcontroller.init
- Added: ovn-controller-vtep.service
- Added: ovn-controller.service
- Added: ovn-northd.service
- TODO: Explicit DPDK support not yet added to spec.
- Spec file work and cleanup.
- Includes fixes (or obsoletes) the following issues:
  * bsc#948840, bsc#941466, bsc#936780, bnc#935750, bnc#867964
* Tue Mar  1 2016 kmroz@suse.com
- Tighten up openvswitch service ordering.
  bsc#968205 (openSUSE), bsc#951314 (SLE).
* Wed Feb 24 2016 kmroz@suse.com
- Don't install INSTALL.* files.
* Wed Feb 24 2016 kmroz@suse.com
- Removed: openvswitch-switch.template
* Wed Feb 24 2016 kmroz@suse.com
- New upstream version 2.4.0
  - Flow table modifications are now atomic, meaning that each packet
    now sees a coherent version of the OpenFlow pipeline.  For
    example, if a controller removes all flows with a single OpenFlow
    "flow_mod", no packet sees an intermediate version of the OpenFlow
    pipeline where only some of the flows have been deleted.
  - Added support for SFQ, FQ_CoDel and CoDel qdiscs.
  - Add bash command-line completion support for ovs-vsctl Please check
    utilities/ovs-command-compgen.INSTALL.md for how to use.
  - The MAC learning feature now includes per-port fairness to mitigate
    MAC flooding attacks.
  - New support for a "conjunctive match" OpenFlow extension, which
    allows constructing OpenFlow matches of the form "field1 in
    {a,b,c...} AND field2 in {d,e,f...}" and generalizations.  For details,
    see documentation for the "conjunction" action in ovs-ofctl(8).
  - Add bash command-line completion support for ovs-appctl/ovs-dpctl/
    ovs-ofctl/ovsdb-tool commands.  Please check
    utilities/ovs-command-compgen.INSTALL.md for how to use.
  - The "learn" action supports a new flag "delete_learned" that causes
    the learned flows to be deleted when the flow with the "learn" action
    is deleted.
  - Basic support for the Geneve tunneling protocol. It is not yet
    possible to generate or match options. This is planned for a future
    release. The protocol is documented at
    http://tools.ietf.org/html/draft-gross-geneve-00
  - The OVS database now reports controller rate limiting statistics.
  - sflow now exports information about LACP-based bonds, port names, and
    OpenFlow port numbers, as well as datapath performance counters.
  - ovs-dpctl functionality is now available for datapaths integrated
    into ovs-vswitchd, via ovs-appctl.  Some existing ovs-appctl
    commands are now redundant and will be removed in a future
    release.  See ovs-vswitchd(8) for details.
  - OpenFlow:
  * OpenFlow 1.4 bundles are now supported for flow mods and port
    mods.  For flow mods, both 'atomic' and 'ordered' bundle flags
    are trivially supported, as all bundled messages are executed
    in the order they were added and all flow table modifications
    are now atomic to the datapath.  Port mods may not appear in
    atomic bundles, as port status modifications are not atomic.
  * IPv6 flow label and neighbor discovery fields are now modifiable.
  * OpenFlow 1.5 extended registers are now supported.
  * The OpenFlow 1.5 actset_output field is now supported.
  * OpenFlow 1.5 Copy-Field action is now supported.
  * OpenFlow 1.5 masked Set-Field action is now supported.
  * OpenFlow 1.3+ table features requests are now supported (read-only).
  * Nicira extension "move" actions may now be included in action sets.
  * "resubmit" actions may now be included in action sets.  The resubmit
    is executed last, and only if the action set has no "output" or "group"
    action.
  * OpenFlow 1.4+ flow "importance" is now maintained in the flow table.
  * A new Netronome extension to OpenFlow 1.5+ allows control over the
    fields hashed for OpenFlow select groups.  See "selection_method" and
    related options in ovs-ofctl(8) for details.
  - ovs-ofctl has a new '--bundle' option that makes the flow mod commands
    ('add-flow', 'add-flows', 'mod-flows', 'del-flows', and 'replace-flows')
    use an OpenFlow 1.4 bundle to operate the modifications as a single
    atomic transaction.  If any of the flow mods in a transaction fail, none
    of them are executed.  All flow mods in a bundle appear to datapath
    lookups simultaneously.
  - ovs-ofctl 'add-flow' and 'add-flows' commands now accept arbitrary flow
    mods as an input by allowing the flow specification to start with an
    explicit 'add', 'modify', 'modify_strict', 'delete', or 'delete_strict'
    keyword.  A missing keyword is treated as 'add', so this is fully
    backwards compatible.  With the new '--bundle' option all the flow mods
    are executed as a single atomic transaction using an OpenFlow 1.4 bundle.
  - ovs-pki: Changed message digest algorithm from MD5 to SHA-1 because
    MD5 is no longer secure and some operating systems have started to disable
    it in OpenSSL.
  - ovsdb-server: New OVSDB protocol extension allows inequality tests on
    "optional scalar" columns.  See ovsdb-server(1) for details.
  - ovs-vsctl now permits immutable columns in a new row to be modified in
    the same transaction that creates the row.
  - test-controller has been renamed ovs-testcontroller at request of users
    who find it useful for testing basic OpenFlow setups.  It is still not
    a necessary or desirable part of most Open vSwitch deployments.
  - Support for travis-ci.org based continuous integration builds has been
    added. Build failures are reported to build@openvswitch.org. See INSTALL.md
    file for additional details.
  - Support for the Rapid Spanning Tree Protocol (IEEE 802.1D-2004).
    The implementation has been tested successfully against the Ixia Automated
    Network Validation Library (ANVL).
  - Stats are no longer updated on fake bond interface.
  - Keep active bond slave selection across OVS restart.
  - A simple wrapper script, 'ovs-docker', to integrate OVS with Docker
    containers. If and when there is a native integration of Open vSwitch
    with Docker, the wrapper script will be retired.
  - Added support for DPDK Tunneling. VXLAN, GRE, and Geneve are supported
    protocols. This is generic tunneling mechanism for userspace datapath.
  - Support for multicast snooping (IGMPv1, IGMPv2 and IGMPv3)
  - Support for Linux kernels up to 4.0.x
  - The documentation now use the term 'destination' to mean one of syslog,
    console or file for vlog logging instead of the previously used term
    'facility'.
  - Support for VXLAN Group Policy extension
  - Initial support for the IETF Auto-Attach SPBM draft standard. This
    contains rudimentary support for the LLDP protocol as needed for
    Auto-Attach.
  - The default OpenFlow and OVSDB ports are now the IANA-assigned
    numbers.  OpenFlow is 6653 and OVSDB is 6640.
  - Support for DPDK vHost.
  - Support for outer UDP checksums in Geneve and VXLAN.
  - The kernel vports with dependencies are no longer part of the overall
    openvswitch.ko but built and loaded automatically as individual kernel
    modules (vport-*.ko).
  - Support for STT tunneling.
  - Support to configure method (--syslog-method argument) that determines
    how daemons will talk with syslog.
  - Support for "ovs-appctl vlog/list-pattern" command that lets to query
    logging message format for each destination.
  - GRE64 and ipsec_gre64 tunnel protocol is deprecated and will be removed
    from OVS v2.5 release.
  * The openvswitch-testcontroller package is new.  It reintroduces the
    simple OpenFlow controller that was packaged with Open vSwitch prior to
    version 2.1, at request of users who find it useful for testing basic
    OpenFlow setups.  It is still not a necessary or desirable part of most
    Open vSwitch deployments.
- Fixed: log-check-module-loop.patch to work with new version.
- Removed: openvswitch-2.3.1.tar.gz
- Added: openvswitch-2.4.0.tar.gz
- Spec file work and cleanup.
* Sun Jan 10 2016 antoine.belvire@laposte.net
- Add calls to /sbin/ldconfig in %%post and %%postun
- Fix typo in Url
* Sun Dec 28 2014 andrea@opensuse.org
- new upstream version 2.3.1
  - Compatibility with autoconf 2.63 (previously >=2.64)
  - ovs-pki: Changed message digest algorithm from MD5 to SHA-1 because
    MD5 is no longer secure and some operating systems have started to disable
    it in OpenSSL.
  - Keep active bond slave selection across OVS restart.
  * v2.3.0 - 14 Aug 2014
  - OpenFlow 1.1, 1.2, and 1.3 are now enabled by default in
    ovs-vswitchd.
  - Linux kernel datapath now has an exact match cache optimizing the
    flow matching process.
  - Datapath flows now have partially wildcarded tranport port field
    matches.  This reduces userspace upcalls, but increases the
    number of different masks in the datapath.  The kernel datapath
    exact match cache removes the overhead of matching the incoming
    packets with the larger number of masks, but when paired with an
    older kernel module, some workloads may perform worse with the
    new userspace.
  * v2.2.0 - Internal Release
  - Internal ports are no longer brought up by default, because it
    should be an administrator task to bring up devices as they are
    configured properly.
  - ovs-vsctl now reports when ovs-vswitchd fails to create a new port or
    bridge.
  - The "ovsdbmonitor" graphical tool has been removed, because it was
    poorly maintained and not widely used.
  - New "check-ryu" Makefile target for running Ryu tests for OpenFlow
    controllers against Open vSwitch.  See INSTALL for details.
  - Added IPFIX support for SCTP flows and templates for ICMPv4/v6 flows.
  - Upon the receipt of a SIGHUP signal, ovs-vswitchd no longer reopens its
    log file (it will terminate instead). Please use 'ovs-appctl vlog/reopen'
    instead.
  - Support for Linux kernels up to 3.14. From Kernel 3.12 onwards OVS uses
    tunnel API for GRE and VXLAN.
  - Added experimental DPDK support.
  - Added support for custom vlog patterns in Python
- removed datapath-Add-support-for-Linux-3.12.patch no more required
- removed sle11-device-ops-backport.diff , not used before
* Tue Oct 21 2014 dmueller@suse.com
- fix rcX link
* Tue Sep 23 2014 dmueller@suse.com
- disable shipped kmp module build for newer distros
* Mon Sep 22 2014 dmueller@suse.com
- update to 2.1.3:
  datapath: Drop packets when interdev is not up
  Fix two memory leaks.
  tests: Remove extraneous parenthesis from test name.
  build: Allow building with autoconf 2.63
  ovsdb: Don't add ovsdb-server.c to libovsdb.
  stp: Make stp-disabled port forward stp bpdu packets.
  dpif-linux: Fix bad backport in previous commit.
  dpif-linux: Avoid null dereference if all ports disappear.
  ofp-msgs: Correct code for queue configuration messages in OpenFlow 1.0.
  ofp-util: Fix null pointer dereference in ofputil_pull_buckets().
  tests: Disable glibc memory checking under glibc <= 2.11.
  datapath/flow_netlink: Fix NDP flow mask validation
  datapath: Change u64_stats_* to use _irq instead of _bh().
  datapath: Use exact lookup for flow_get and flow_del.
  json: Fix parsing of strings that end with a backslash.
  dpif: When executing actions needs help, use "set" action to set tunnel.
  datapath: Rehash 16-bit skbuff hashes into 32 bits.
  upcall: Configure datapath max-idle through ovs-vsctl.
  upcall: Add appctl call to set flow_limit.
  stream-ssl: Enable TLSv1.1 and TLSv1.2.
  lib/classifier: Fix use of uninitialized memory.
  lib/classifier: Clarify trie_lookup_value().
  ovs-lib: allow non-root users to check service status
  rhel: Add Patch Port support to initscripts
  rhel: support persistent mac addresses on OVS bridges
  netflow: Fold netflow_expire() into netflow_flow_clear().
  ofproto: Fix memory leak in ofproto_destroy().
  ofproto: Send monitor updates if a flow mod changes a rules actions
  lib/match: Add mask bits for nd_target for ICMPv6
  bridge: Initialize dscp for mgmt connections.
  datapath: Fix build from stats backport.
  openvswitch: fix a possible deadlock and lockdep warning
  AUTHORS: Fix spelling of Anoob Soman's name.
  ofproto-dpif-xlate: Fix null pointer dereference
  ovs-ctl: Don't decrease max open fds if already set higher
  Makefiles: Fix invocation of dot2pic when builddir != srcdir.
  dot2pic: Stop assuming the path of the interpreter
  dot2pic: Use "> $@; mv $@.tmp $@" notation to make this reliably fail
  tunnel: Fix bug where misconfiguration persists.
  netdev: Safely increment refcount in netdev_open().
  datapath: Fix feature check for HAVE_RXHASH.
  datapath: clear l4_rxhash in skb_clear_hash.
  ofproto-dpif-xlate: Fix in_port=controller case for NORMAL action
* Fri May  2 2014 e.istomin@edss.ee
- updated to 2.1.2.
  This contains bug fixes related to sending packet-in messages to the controller.
* Tue Apr 29 2014 e.istomin@edss.ee
- updated to 2.1.1. This release removes the "ovsdbmonitor" program and contains bug fixes.
* Wed Apr  2 2014 kmroz@suse.com
- Prevent ovsdb-server from entering an infinite loop when
  processing logging levels during bringup.
  added: log-check-module-loop.patch
* Thu Mar 27 2014 dmueller@suse.com
- update to 2.1.0:
  - Address prefix tracking support for flow tables.  New columns
    "prefixes" in OVS-DB table "Flow_Table" controls which packet
    header fields are used for address prefix tracking.  Prefix
    tracking allows the classifier to skip rules with longer than
    necessary prefixes, resulting in better wildcarding for datapath
    flows.  Default configuration is to not use any fields for prefix
    tracking.  However, if any flow tables contain both exact matches
    and masked matches for IP address fields, OVS performance may be
    increased by using this feature.
  * As of now, the fields for which prefix lookup can be enabled
    are: 'tun_id', 'tun_src', 'tun_dst', 'nw_src', 'nw_dst' (or
    aliases 'ip_src' and 'ip_dst'), 'ipv6_src', and 'ipv6_dst'.
    (Using this feature for 'tun_id' would only make sense if the
    tunnel IDs have prefix structure similar to IP addresses.)
  * There is a maximum number of fields that can be enabled for any
    one flow table.  Currently this limit is 3.
  * Examples:
    $ ovs-vsctl set Bridge br0 flow_tables:0=@N1 -- \
  - -id=@N1 create Flow_Table name=table0
    $ ovs-vsctl set Bridge br0 flow_tables:1=@N1 -- \
  - -id=@N1 create Flow_Table name=table1
    $ ovs-vsctl set Flow_Table table0 prefixes=ip_dst,ip_src
    $ ovs-vsctl set Flow_Table table1 prefixes=[]
  - TCP flags matching: OVS now supports matching of TCP flags.  This
    has an adverse performance impact when using OVS userspace 1.10
    or older (no megaflows support) together with the new OVS kernel
    module.  It is recommended that the kernel and userspace modules
    both are upgraded at the same time.
  - The default OpenFlow and OVSDB ports will change to
    IANA-assigned numbers in a future release.  Consider updating
    your installations to specify port numbers instead of using the
    defaults.
  - OpenFlow:
  * The OpenFlow 1.1+ "Write-Actions" instruction is now supported.
  * OVS limits the OpenFlow port numbers it assigns to port 32767 and
    below, leaving port numbers above that range free for assignment
    by the controller.
  * ovs-vswitchd now honors changes to the "ofport_request" column
    in the Interface table by changing the port's OpenFlow port
    number.
  - ovs-vswitchd.conf.db.5 man page will contain graphviz/dot
    diagram only if graphviz package was installed at the build time.
  - Support for Linux kernels up to 3.11
  - ovs-dpctl:
    The "show" command also displays mega flow mask stats.
  - ovs-ofctl:
  * New command "ofp-parse-pcap" to dump OpenFlow from PCAP files.
  - ovs-controller has been renamed test-controller.  It is no longer
    packaged or installed by default, because too many users assumed
    incorrectly that ovs-controller was a necessary or desirable part
    of an Open vSwitch deployment.
  - Added vlog option to export to a UDP syslog sink.
  - ovsdb-client:
  * The "monitor" command can now monitor all tables in a database,
    instead of being limited to a single table.
  - The flow-eviction-threshold has been replaced by the flow-limit which is a
    hard limit on the number of flows in the datapath.  It defaults to 200,000
    flows.  OVS automatically adjusts this number depending on network
    conditions.
* Thu Mar 27 2014 dmueller@suse.com
- allow to use kmod as well
* Mon Feb  3 2014 dmueller@suse.com
- another fix in logrotate
* Mon Jan 27 2014 dmueller@suse.com
- fix logrotate configuration
* Tue Jan 21 2014 dmueller@suse.com
- add openvswitch.service for systemd distros
* Tue Jan 14 2014 dmueller@suse.com
- add kernel-312.diff (build against Kernel 3.12.x)
* Fri Jan  3 2014 dmueller@suse.com
- do not build with valgrind-devel on aarch64 (doesn't exist)
* Thu Dec  5 2013 dmueller@suse.com
- update to 2.0.0:
  - The ovs-vswitchd process is no longer single-threaded.  Multiple
    threads are now used to handle flow set up and asynchronous
    logging.
  - OpenFlow:
  * Experimental support for OpenFlow 1.1 (in addition to 1.2 and
    1.3, which had experimental support in 1.10).
  * New support for matching outer source and destination IP address
    of tunneled packets, for tunnel ports configured with the newly
    added "remote_ip=flow" and "local_ip=flow" options.
  * Support for matching on metadata 'pkt_mark' for interacting with
    other system components. On Linux this corresponds to the skb
    mark.
  * Support matching, rewriting SCTP ports
  - The Interface table in the database has a new "ifindex" column to
    report the interface's OS-assigned ifindex.
  - New "check-oftest" Makefile target for running OFTest against Open
    vSwitch.  See README-OFTest for details.
  - The flow eviction threshold has been moved to the Open_vSwitch table.
  - Database names are now mandatory when specifying ovsdb-server options
    through database paths (e.g. Private key option with the database name
    should look like "--private-key=db:Open_vSwitch,SSL,private_key").
  - Added ovs-dev.py, a utility script helpful for Open vSwitch developers.
  - Support for Linux kernels up to 3.10
  - ovs-ofctl:
  * New "ofp-parse" for printing OpenFlow messages read from a file.
  - Added configurable flow caching support to IPFIX exporter.
  - Dropped support for Linux pre-2.6.32.
  - Log file timestamps and ovsdb commit timestamps are now reported
    with millisecond resolution.  (Previous versions only reported
    whole seconds.)
* Wed Dec  4 2013 jsuchome@suse.cz
- added try-restart action to openvswitch-switch init script
  (bnc#849222)
* Wed Nov 20 2013 kmroz@suse.com
- Incorporate ubuntu Linux 3.11 fix to prevent kernel datapath panics.
  Addresses bnc#851395
  + added datapath-add-support-for-linux-3.11.patch
* Tue Oct  1 2013 speilicke@suse.com
- Let openvswitch-switch depend on util-linux instead of uuid-runtime
  (Debian package name). The ovs-ctl / ovs-pki tools use /usr/bin/uuidgen
* Tue Sep 24 2013 bwiedemann@suse.com
- add vlan_apichange.patch to compensate kernel API changes
  between 3.8 and 3.11 in commits f646968f and 86a9bad3
* Fri Sep 13 2013 dmueller@suse.com
- update to 1.11.0:
  * http://openvswitch.org/releases/NEWS-1.11.0
- remove accept-newer-kernel-versions.diff
* Fri Sep 13 2013 dmueller@suse.com
- sign modules for secure boot (bnc#839838)
* Tue Jul  2 2013 tpaszkowski@novell.com
- Build openvswitch kernel module for xen kernel flavor.
* Sun Jun 16 2013 vuntz@suse.com
- Add openvswitch-ipsec.init, Module.supported,
  Module.supported.updates and README.packager as sources: they
  were not listed as such.
- Install openvswitch-ipsec.init if we build ipsec support.
* Thu Jun  6 2013 tpaszkowski@novell.com
- mark openvswitch module shipped with package as supported
* Fri May 17 2013 dmueller@suse.com
- only call boot.sh for newer distros
- build parallel
- accept-newer-kernel-versions.diff:
  Accept newer kernel versions
- sle11-device-ops-backport.diff
  Handle sle11 device ops backport
* Fri May  3 2013 e.istomin@edss.ee
- New upstream version 1.10.0
  http://openvswitch.org/releases/NEWS-1.10.0
- Removed openvswitch-1.7.0-stp-fwd-delay.patch because of bridge compatibility support removing
* Wed Apr  3 2013 tpaszkowski@novell.com
- %%make_install macro no longer works on SLE11. Spec file now uses %%makeinstall.
* Tue Mar 26 2013 speilicke@suse.com
- Use build conditionals instead of %%define and disable GUI by default
  everywhere
* Thu Mar 21 2013 tpaszkowski@novell.com
- Fix openvswitch-controller init script
- Add openflow-controller sysconfig file with default binding to ptcp:
* Tue Mar 12 2013 tpaszkowski@suse.com
- ipsec build temporary disabled
* Fri Mar  8 2013 tpaszkowski@suse.com
- Provides and Obsolete for former openvswitch-common package
* Thu Mar  7 2013 tpaszkowski@suse.com
- always build in openvswitch kernel module (gre tunelling not present
  within the standard kernel module)
- removed unnedded build rquirements (move to appropriate subpackage)
- moved common stuff to main pkg
- added group filed to packages and sub packages
- switch pkg suggest kernel module pkg
- moved python test stuff to python-openvswitch-test sub pkg
- moved ui interface requirements to ovsdbmonitor sub pkg
- ovsdbmonitor will not be build on sles (for now)
- sub pkg test require python-twisted (ovs-test)
- don't call boot.sh on sles11 (old autoconf). Shipped configuration stuff
  is ok (we don't patch plenty of stuff)
- ovs-parse-backtrace now part of main pkg
- addes ovs-l3ping,ovs-vlan-test to test sub pkg
* Thu Feb 28 2013 e.istomin@edss.ee
- New upstream version 1.9.0
  http://openvswitch.org/releases/NEWS-1.9.0
* Thu Nov 15 2012 rhafer@suse.com
- New patch openvswitch-1.7.1-ovs-pki-permissions.patch: Avoid
  creating world writeable directory (bnc#774332, CVE-2012-3449)
* Sun Sep  9 2012 on@morlock.nu
- New upstream version 1.7.1
  * This release only contain bug fixes.
* Tue Jul 31 2012 on@morlock.nu
- New upstream version 1.7.0
  * kernel modules are renamed. openvswitch_mod.ko is now
    openvswitch.ko and brcompat_mod.ko is now brcompat.ko.
  * Increased the number of NXM registers to 8.
  * Added ability to configure DSCP setting for manager and controller
    connections.  By default, these connections have a DSCP value of
    Internetwork Control (0xc0).
  * Added the granular link health statistics, 'cfm_health', to an
    interface.
  * OpenFlow:
  - Added support to mask nd_target for ICMPv6 neighbor discovery flows.
  - Added support for OpenFlow 1.3 port description (OFPMP_PORT_DESC)
    multipart messages.
  * ovs-ofctl:
  - Added the "dump-ports-desc" command to retrieve port
    information using the new port description multipart messages.
  * ovs-test:
  - Added support for spawning ovs-test server from the client.
  - Now ovs-test is able to automatically create test bridges and ports.
  * "ovs-dpctl dump-flows" now prints observed TCP flags in TCP flows.
  * Tripled flow setup performance.
  * The "coverage/log" command previously available through ovs-appctl
    has been replaced by "coverage/show".  The new command replies with
    coverage counter values, instead of logging them.
- Adjusted openvswitch-1.1.0-stp-fwd-delay.patch (new filename)
* Thu Jul 26 2012 rhafer@suse.com
- The kernel modules where renamed in recent kernels. Backported a
  patch from the 1.7 branch to use the new kernel names when
  building on openSUSE > 12.1.
* Tue Jun 26 2012 on@morlock.nu
- New upstream version 1.6.1
  * Added support for bitwise matching on TCP and UDP ports.
  * Support for limiting the number of flows in an OpenFlow flow
    table, with configurable policy for evicting flows upon
    overflow.
  * Added an OpenFlow extension that allows controllers more precise
    control over which messages they receive asynchronously.
  * CFM module CCM broadcasts can now be tagged with an 802.1p priority.
  * Load balancing for bonds can be disabled.
* Wed Jun  6 2012 on@morlock.nu
- New upstream version 1.5.0
  * OpenFlow:
  - Added support for querying, modifying, and deleting flows
    based on flow cookie when using NXM.
  - Added new NXM_PACKET_IN format.
  * ovs-ofctl:
  - Added daemonization support to the monitor and snoop commands.
  * ovs-vsctl:
  - The "find" command supports new set relational operators
    {=}, {!=}, {<}, {>}, {<=}, and {>=}.
  * ovsdb-tool now uses the typical database and schema installation
    directories as defaults.
* Thu May 10 2012 on@morlock.nu
- New upstream version 1.4.1
  * The default MAC learning timeout has been increased from 60 seconds
    to 300 seconds. The MAC learning timeout is now configurable.
  * Bug fixes
* Thu Apr  5 2012 on@morlock.nu
- Build KMP packages from kernel-source on openSuSE > 12.1.
* Tue Mar 13 2012 mvidner@suse.com
- Specify defattr for pki subpackage to fix 11.4 build.
* Thu Mar  1 2012 dmacvicar@suse.de
- Rewrite the package based on the debian version instead
  * current package was tied to xenserver config without
    even requiring it
  * instead of one big package depending even on qt4, there
    are -switch, -controller, -test subpackages now
* Mon Feb 20 2012 on@morlock.nu
- New upstream version 1.4.0
  * Compatible with Open vSwitch kernel module included in Linux 3.3.
  * Don't require the "normal" action to use mirrors.
  * New "VLAN splinters" feature to work around buggy device driver in old Linux versions.
  * Added ability to match ECN and TTL in IPv4 and IPv6 headers.
  * Added ability to match IPv6 flow label.
  * Added ability to modify ECN bits and TTL in IPv4 headers.
  * And many others. See the full change log here:
  http://openvswitch.org/releases/NEWS-1.4.0
* Fri Sep  2 2011 andrea@opensuse.org
- new uopstream version 1.2.1
  * The release only contains bug fixes for the 1.2.0 release
* Mon Aug  8 2011 andrea@opensuse.org
- new upstream version 1.2.0
  * New abstraction layer to make better use of switching ASICs
  * Packaging for Red Hat (RHEL) 5.6 and 6.0
  * Datapath support for Linux kernels up to 3.0
  * And many others.  See the full change log here:
    http://openvswitch.org/releases/ChangeLog-1.2.0
- rebased openvswitch-1.1.0-suse.patch as
  openvswitch-1.2.0-suse.patch to apply to the files
* Thu Jun 23 2011 andrea@opensuse.org
- new upstream version 1.1.1
  * bug fix release
* Wed May 18 2011 andrea@opensuse.org
- re-enabled kmp package since openvswitch_mod.ko and
  brcompat_mod.ko are not available on suse kernel rpms
* Tue May 17 2011 andrea@opensuse.org
- new upstream version 1.1.0 (stable)
- spec file clean up
- added as dependency all python modules to enable additional
  functionalities
- rebase patches
- build pyside support only if pyside is available
* Fri Dec 31 2010 pmullaney@novell.com
- updates for build issues
- fixes for libvirt integration
* Sat Dec 11 2010 pmullaney@novell.com
- initial version 1.1
